#!/bin/bash

## Packager : Jean-Philippe Guillemin <jp.guillemin@free.fr>
## Sources : http://www.gratisoft.us/sudo/dist/sudo-1.7.2p4.tar.gz

soft='sudo'
softversion='1.7.2p4'
packageversion='64.1'

arch='i486'
cpu='i686'

CWD=$(pwd)
srcpkg="$CWD/$soft-$softversion.tar.gz"
src="$CWD/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
PKG="/tmp/$package"

cd $CWD
rm -rf $src
tar -xvf $srcpkg
rm -f $PKG.tgz
rm -rf $PKG
mkdir -p $PKG
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

./configure --prefix=/usr \
			--sbindir=/usr/sbin \
			--mandir=/usr/man \
			--with-getpass \
			--with-hal-insults \
			--with-C2 \
			--with-pam
make || exit 1
make install DESTDIR=$PKG
( cd $PKG/usr/bin
  chmod 4711 sudo
  ln -sf sudo sudoedit
)

chmod 755 $PKG/usr/sbin/visudo
rm -f $PKG/usr/man/man8/sudoedit.8

gzip -9 $PKG/usr/man/man?/*.?

( cd $PKG/usr/man/man8 ; ln -sf sudo.8.gz sudoedit.8.gz )

find $PKG | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $PKG/usr/doc/sudo-$softversion
cp -a \
  ChangeLog HISTORY INSTALL* LICENSE PORTING README* TROUBLESHOOTING WHATSNEW \
  $PKG/usr/doc/sudo-$softversion
chmod 644 $PKG/usr/doc/sudo-$softversion/*

rm $PKG/etc/sudoers 

cat << "EOF" > $PKG/etc/sudoers.new
# sudoers file.
#
# This file MUST be edited with the 'visudo' command as root.
#
# See the sudoers man page for the details on how to write a sudoers file.
#

# Host alias specification

# User alias specification

# Cmnd alias specification

# Defaults specification

# Runas alias specification

# User privilege specification
root	ALL=(ALL) ALL

%users ALL = (ALL) NOPASSWD:/usr/libexec/xfsm-shutdown-helper
%cdrom ALL = (ALL) NOPASSWD:/usr/sbin/hibernate 
%cdrom ALL = (ALL) NOPASSWD:/usr/sbin/standby 

# Uncomment to allow people in group wheel to run all commands
# %wheel	ALL=(ALL)	ALL

# Same thing without a password
# %wheel	ALL=(ALL)	NOPASSWD: ALL

# Samples
# %users  ALL=/sbin/mount /cdrom,/sbin/umount /cdrom
# %users  localhost=/sbin/shutdown -h now
EOF

chmod 440 $PKG/etc/sudoers.new

# PAM auth policy
mkdir -p $PKG/etc/pam.d
cat << "EOF" > $PKG/etc/pam.d/sudo.new
auth         required    pam_env.so
auth         sufficient  pam_unix.so
account      include     system-auth
password     include     system-auth
session      required    pam_limits.so
session      required    pam_unix.so
EOF

mkdir -p $PKG/install
cat << "EOF" > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler--------------------------------------------------------|
sudo: sudo - give limited root privileges to certain users
sudo:
sudo: 'sudo' is a command that allows users to execute some commands as 
sudo: root.  The /etc/sudoers file (edited with 'visudo') specifies which
sudo: users have access to sudo and which commands they can run.  'sudo'
sudo: logs all its activities to /var/log/ so the system administrator
sudo: can keep an eye on things.
sudo:
sudo:
sudo:
sudo:
EOF

cat << "EOF" >> $PKG/install/doinst.sh
#!/bin/sh

function config() {
	NEW="$1"
	OLD="`dirname $NEW`/`basename $NEW .new`"
	# If there's no config file by that name, mv it over:
	if [ ! -r $OLD ]; then
		mv $NEW $OLD
	elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
		# toss the redundant copy
		rm $NEW
	fi
}

config etc/pam.d/sudo.new
config etc/sudoers.new
EOF

mkdir -p $PKG/usr/src/$soft-$softversion
( cd $CWD
cp -a build-$soft.sh $PKG/usr/src/$soft-$softversion/
)

cd $PKG
makepkg -l y -c n $PKG.txz
makepkg -l y -c n $PKG.tgz

# cleanup

rm -rf $PKG
rm -rf $src
